@@ -5,7 +5,7 @@ import subprocess
 from datetime import datetime
 from typing import List, Dict, Any, Optional
 import os
-
+import httpx
 from openai import OpenAI
 from pydantic import BaseModel
 from rich.console import Console
@@ -34,7 +34,20 @@ def get_openai_client() -> OpenAI:
     api_key = os.environ.get("OPENAI_API_KEY")
     if not api_key:
         raise ValueError("OPENAI_API_KEY environment variable is required")
-    return OpenAI(api_key=api_key)
+    
+    # Create httpx client with default settings
+    http_client = httpx.Client(
+        timeout=60.0,
+        follow_redirects=True
+    )
+    
+    # Create OpenAI client with custom httpx client
+    client = OpenAI(
+        api_key=api_key,
+        http_client=http_client
+    )
+    
+    return client
 
 
 class CommitMessage(BaseModel):
